@@ -39,7 +39,7 @@ from pre_workbench import windows
 from pre_workbench.configs import getIcon
 from pre_workbench.datawidgets import DynamicDataWidget
 from pre_workbench.util import get_app_version, SimpleThread
-from pre_workbench.windows.dialogs.manageannotationsets import showManageAnnotationSetsDialog
+from pre_workbench.windows.dialogs.manageannotationsets import ManageAnnotationSetsDialog
 from pre_workbench.windows.dockwindows import FileBrowserWidget, MdiWindowListWidget, StructInfoTreeWidget, \
 	StructInfoCodeWidget, DataInspectorWidget, BinwalkDockWidget, ExtToolDockWidget, SearchDockWidget
 from pre_workbench.windows.dockwindows import RangeTreeDockWidget, RangeListWidget, SelectionHeuristicsConfigWidget, LogWidget
@@ -205,7 +205,7 @@ class WorkbenchMain(QMainWindow):
 		self.mapChildAction(self.clearRangesAct, "clearRanges")
 
 		self.manageAnnotationSetsAct = QAction("&Manage Annotation Sets", self,
-				triggered=lambda: showManageAnnotationSetsDialog(self))
+				triggered=lambda: ManageAnnotationSetsDialog(self).exec())
 
 
 
@@ -511,8 +511,12 @@ class WorkbenchMain(QMainWindow):
 
 	def openProjectInNewWindow(self, projectPath = "--choose-project"):
 		import subprocess
-		subprocess.Popen([sys.executable, sys.argv[0], projectPath], stdin=subprocess.DEVNULL, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
-
+		self_script = sys.argv[0]
+		# weird Windows magic
+		if not os.path.exists(self_script) and os.path.exists(self_script + '.exe'): self_script += '.exe'
+		cmd_line = [sys.executable, self_script, projectPath]
+		logging.info('Starting new instance with cmd line: %r', cmd_line)
+		subprocess.Popen(cmd_line, stdin=subprocess.DEVNULL, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
 
 	def onFileNewWindowAction(self, typ):
 		ow = typ()
